lx_selector: select lights

Description Usage Arguments Details

View source: R/selector.R

Description

use this function to select lights that you want to communicate with

Usage

1
2
3
4
5
6
7
8
9
lx_selector(
  id = NULL,
  label = NULL,
  group_id = NULL,
  group = NULL,
  location_id = NULL,
  location = NULL,
  zones = NULL
)

Arguments

id

the id of the lamp(s) to select

label

the label of the lamp(s) to select

group_id

the group_id of the lamp(s) to select

group

the group of the lamp(s) to select

location_id

the location_id of the lamp(s) to select

location

the location of the lamp(s) to select

zones

the zones of the lamp(s) to select

Details

this creates strings to select lamps in the format that the lifx api expects (see https://api.developer.lifx.com/docs/selectors). This function is intended to be used to create a 'selector' that is then passed to a function that changes the state of the lamps.


mabafaba/lifx documentation built on June 8, 2020, 3:46 a.m.