Description Usage Arguments Details
use this function to select lights that you want to communicate with
1 2 3 4 5 6 7 8 9 |
id |
the id of the lamp(s) to select |
label |
the label of the lamp(s) to select |
group_id |
the group_id of the lamp(s) to select |
group |
the group of the lamp(s) to select |
location_id |
the location_id of the lamp(s) to select |
location |
the location of the lamp(s) to select |
zones |
the zones of the lamp(s) to select |
this creates strings to select lamps in the format that the lifx api expects (see https://api.developer.lifx.com/docs/selectors). This function is intended to be used to create a 'selector' that is then passed to a function that changes the state of the lamps.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.